@@ -1,7 +1,7 @@
 bf.test <- function (formula, data, alpha = 0.05, na.rm = TRUE, verbose = TRUE){
   
-
-  dp=as.character(formula)
+  data <- model.frame(formula, data)
+  dp <- as.character(formula)
   DNAME <- paste(dp[[2L]], "and", dp[[3L]])
 
   METHOD <- "Brown-Forsythe Test"
